.. _install_instructions:

############
Installation
############

Fitbenchmarking will install all packages that can be installed through pip.
This includes the minimizers from SciPy, bumps, DFO-GN/LS, Minuit, and
also the SASModels package.

To enable Fitbenchmarking with the other supported software,
you must install them with the external software instructions.


.. toctree::
    :titlesonly:
    :maxdepth: 2
    :caption: Software:

    fitbenchmarking
    externals
